%%
%%    File : smid.cls    (LaTeX2e class file)
%%  Author : Paola Magillo, thanks to Davide Ancona
%% Version : 1.0 [March 2017]
%%
%% Definizione di classe di stile LaTeX2e per prove finali del
%% corso di Laurea Triennale in Statistica Matematica e Trattamento 
%% Informatico dei Dati (SMID) presso l'Universita' di Genova.
%%

\NeedsTeXFormat{LaTeX2e}[1994/12/01]
\ProvidesClass{smid}[2017/03/20 v1.0]

%%
%%  --- Options ---
%%
%%  Current options: all report.cls options
%%
%%  Default:         12pt,a4paper
%%                   + all remaining report.cls default options

\DeclareOption{draft}{ % with this option images are not loaded
   \PassOptionsToClass{draft}{report}}

\DeclareOption{10pt}{  \PassOptionsToClass{10pt}{report}}
\DeclareOption{11pt}{  \PassOptionsToClass{11pt}{report}}
\DeclareOption{12pt}{  \PassOptionsToClass{12pt}{report}}

\DeclareOption{twoside}{\PassOptionsToClass{twoside,openright}{report}}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}

\ExecuteOptions{12pt,a4paper} % the default options
\ProcessOptions

%%
%% --- Class Loading (built ontop of report.cls) ---
%%

\LoadClass[a4paper,12pt]{report}

%%
%% Set margins 
%%

\topmargin 0cm
\headsep 1cm
\headheight 0.6cm
\textwidth 14.6cm
\textheight 21.9cm
\evensidemargin 1cm
\oddsidemargin 1cm

%%
%% And now setup that headings style as default
%%

\newcommand{\@textpagenumbering}{arabic}
\newcommand{\@preamblepagenumbering}{roman}
\newcommand{\@textpagestyle}{plain}
\newcommand{\@preamblepagestyle}{plain}

\pagestyle{\@preamblepagestyle}

\setcounter{secnumdepth}{6}

% Imposto la lingua italiana
\usepackage[italian]{babel}

%%
%% Set up the default names for the various chapter headings
%%

\renewcommand{\chaptername}{Capitolo}
\renewcommand{\contentsname}{Indice}
\renewcommand{\listfigurename}{Lista delle figures}
\renewcommand{\listtablename}{Lista delle tabelle}
\renewcommand{\bibname}{Bibliografia}
\renewcommand{\indexname}{Indice}
\renewcommand{\abstractname}{Sommario}

%%
%% Set up the double spacing and provide commands to alter the
%% spacing for the subsequent text. 
%% This can be modified through the singlespacing, doublespacing
%% or draft class options.
%%

\newcommand{\doublespace}{\baselineskip 24pt
                          \parskip 24pt
                          \parsep 26.4pt}
\newcommand{\oneandahalfspace}{\baselineskip 18pt
                               \parskip 19.8pt
                               \parsep 19.8pt}
\newcommand{\singlespace}{\baselineskip 14.4pt
                          \parskip 7.2pt
                          \parsep 7.2pt}

%%
%% When printing twosided, then the title page must be followed by
%% a blank page so that the thesis begins on the right-hand page. 
%% Also we must ensure that the thesis ends on a lef-hand page. We
%% do the latter by issuing a \cleardoublepage at the end of document.
%%

\newcommand{\cscleardoublepage}%
  {\newpage{\pagestyle{empty}
   \cleardoublepage}}
\AtEndDocument{\cscleardoublepage}

%%
%% Now let's redefine the abstract env. so that the title is 
%% comparable to other chapter headings. Also have abstract
%% start at top of page instead of floating in the middle
%%

\renewenvironment{abstract}
   {\cscleardoublepage
    \titlepage\null\vspace{1cm}
    \begin{center}
       \bfseries \LARGE\abstractname
    \end{center}}
   {\par\vfil\null\endtitlepage}

%%
%% Based upon the above abstract env., provide wrappers for
%% an acknowledgements env.
%%

\newenvironment{acknowledgements}
   {\renewcommand{\abstractname}{Ringraziamenti}\begin{abstract}}
   {\end{abstract}\renewcommand{\abstractname}{Abstract}}   

%%
%% Format for the title page is set by redefining \maketitle, and
%% allowing extra input options: \relatore \correlatore and
%% \annoaccademico, while option \date is not used
%%

\def\annoaccademico#1{\gdef\@annoaccademico{#1}}
\gdef\@annoaccademico{\the\year}

\def\relatore#1{\gdef\@relatore{#1}}
\def\correlatore#1{\gdef\@correlatore{#1}}

\renewcommand{\maketitle}{
\begin{titlepage}
{\begin{center}
 \textsc{ \LARGE{Universit\`a\ degli \ Studi\ di\ Genova}}\\[0.3cm]
 \includegraphics[scale=0.2]{unige.png}\\[0.5cm]
 \textsc{ \large Dipartimento di Matematica}\\[1.3cm]
 \textsc{ \Large Corso di studi in}\\[0.8cm]
 \textsc{ {\LARGE Statistica Matematica e}}\\[0.3cm]
 \textsc{ {\LARGE trattamento Informatico dei Dati}}\\[0.5cm]
 \includegraphics[scale=0.6]{smid.png}\\[1.3cm]
 {\Large Prova Finale}\\[0.7cm]  
 {\LARGE \textbf{ \@title }}\\[1.7cm]
 {\LARGE \textbf{Candidato}}\\[0.8cm]
 {\LARGE \@author }\\[1.2cm]
 \begin{tabular}{ccc}
 {\Large\textbf{ Relatore}} & \hspace{3cm} & {\Large\textbf{ Correlatore}}\\[0.4cm]
 {\Large \@relatore     } &              & {\Large \@correlatore}\\
 \end{tabular}\\[1cm]
 \Large Anno accademico \@annoaccademico
\end{center}}
\end{titlepage}
}

% Pacchetti da includere per...

% formattazione teoremi
\usepackage{amsthm}

% simboli matematici
\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{amsfonts}

% figure
\usepackage{epsfig}
\usepackage{graphicx}

% riferimenti cliccabili nel pdf
\usepackage[pdftex]{hyperref}

% extended array and tabular environments
\usepackage{array}

%%
%% Configurazioni varie
%%

% nonumchapter serve per introduzioni, prefazioni, ecc.
% titola come un capitolo ma senza numero
\def\nonumchapter#1{
	\chapter*{#1}
	\addcontentsline{toc}{chapter}{#1}
}

% estensioni e cartella delle immagini (non necessario...)
\DeclareGraphicsExtensions{gif,eps,png,jpeg}
\graphicspath{{./eps/}}
 
%%
%% COMANDI E ANBIENTI
%%

% permette l'inserimento "rapido" del virgolettato (ad es. per citazioni)
\newcommand{\virgolette}[1]{``#1''}

\newtheorem{theorem}{Teorema}[chapter]
\newtheorem{definition}[theorem]{Definizione}
\newtheorem{lemma}[theorem]{Lemma}
\newtheorem{corollary}[theorem]{Corollario}
\newtheorem{proposition}[theorem]{Proposizione}
\newtheorem{remark}[theorem]{Osservazione}
\newtheorem{example}[theorem]{Esempio}
\renewcommand{\labelenumi}{(\alph{enumi})}

%%
%% EOF: smid.cls
%%
